@@ -6,23 +6,22 @@
 #' @param boundary  Character string specifying the boundary condition. If boundary=="periodic" the default, then the vector you decompose is assumed to be periodic on its defined interval, if boundary=="reflection", the vector beyond its boundaries is assumed to be a symmetric reflection of itself.
 #' @param cov.opt   Options of Covariance matrix sign. Use "pos", "neg", or "auto".
 #' @param flag      Biased or Unbiased variance transformation, c("biased","unbiased").
-#' @param detrend   Detrend the input time series or just center, default (F)
+#' @param detrend   Detrend the input time series or just center, default (F).
 #'
 #' @return A list of 8 elements: wf, J, boundary, x (data), dp (data), dp.n (variance transformed dp), and S (covariance matrix).
 #' @import waveslim
 #' @export
 #'
 #' @references Jiang, Z., Sharma, A., & Johnson, F. (2020). Refining Predictor Spectral Representation Using Wavelet Theory for Improved Natural System Modeling. Water Resources Research, 56(3), e2019WR026962.
-#'
-#' Jiang, Z., Sharma, A., & Johnson, F. (2021). Variable transformations in the spectral domain – Implications for hydrologic forecasting. Journal of Hydrology, 126816.
+#' @references Jiang, Z., Sharma, A., & Johnson, F. (2021). Variable transformations in the spectral domain – Implications for hydrologic forecasting. Journal of Hydrology, 126816.
 #'
 #' @examples
 #' data(rain.mon)
 #' data(obs.mon)
 #'
 #' ## response SPI - calibration
-#' # SPI.cal <- SPI.calc(window(rain.mon, start=c(1949,1), end=c(1979,12)),sc=12)
-#' SPI.cal <- SPEI::spi(window(rain.mon, start = c(1949, 1), end = c(1979, 12)), scale = 12)$fitted
+#' SPI.cal <- SPI.calc(window(rain.mon, start=c(1949,1), end=c(1979,12)),sc=12)
+#' #SPI.cal <- SPEI::spi(window(rain.mon, start = c(1949, 1), end = c(1979, 12)), scale = 12)$fitted
 #'
 #' ## create paired response and predictors dataset for each station
 #' data.list <- list()
@@ -61,6 +60,7 @@ at.vt <- function(data, wf, J, boundary, cov.opt = "auto",
   n <- nrow(dp)
   S <- matrix(nrow = J + 1, ncol = ndim)
   dp.n <- matrix(nrow = n, ncol = ndim)
+  Wn.list <- vector('list', NCOL(dp))
 
   for (i in 1:ndim) {
     # center or detrend
@@ -76,11 +76,11 @@ at.vt <- function(data, wf, J, boundary, cov.opt = "auto",
     B <- matrix(unlist(at.dp), ncol = J + 1, byrow = FALSE)
 
     Bn <- scale(B)
+    Wn.list[[i]] <- Bn
     V <- as.numeric(apply(B, 2, sd))
 
     dif <- sum(abs(Bn %*% V - dp.c))
-    if (dif > 10^-10) print(paste0("Difference between reconstructed and
-                                   original series: ", dif))
+    if (dif > 10^-10) print(paste0("Difference between reconstructed and original series: ", dif))
 
     # variance transformation
     cov <- cov(x, Bn[seq_len(length(x)), ])
@@ -134,7 +134,8 @@ at.vt <- function(data, wf, J, boundary, cov.opt = "auto",
     x = x,
     dp = dp,
     dp.n = dp.n,
-    S = S
+    S = S,
+    Wn = Wn.list
   )
   class(dwt) <- "at"
 
@@ -146,10 +147,11 @@ at.vt <- function(data, wf, J, boundary, cov.opt = "auto",
 #' @param data		  A list of response x and dependent variables dp.
 #' @param J      	  Specifies the depth of the decomposition. This must be a number less than or equal to log(length(x),2).
 #' @param dwt       A class of "at" data. Output from at.vt().
-#' @param detrend   Detrend the input time series or just center, default (F)
+#' @param detrend   Detrend the input time series or just center, default (F).
 #'
 #' @return A list of 8 elements: wf, J, boundary, x (data), dp (data), dp.n (variance transformed dp), and S (covariance matrix).
 #' @export
+#'
 #' @references Jiang, Z., Sharma, A., & Johnson, F. (2020). Refining Predictor Spectral Representation Using Wavelet Theory for Improved Natural System Modeling. Water Resources Research, 56(3), e2019WR026962. doi:10.1029/2019wr026962
 #'
 #' @examples
@@ -157,8 +159,8 @@ at.vt <- function(data, wf, J, boundary, cov.opt = "auto",
 #' data(obs.mon)
 #'
 #' ## response SPI - calibration
-#' # SPI.cal <- SPI.calc(window(rain.mon, start=c(1949,1), end=c(1979,12)),sc=12)
-#' SPI.cal <- SPEI::spi(window(rain.mon, start = c(1949, 1), end = c(1979, 12)), scale = 12)$fitted
+#' SPI.cal <- SPI.calc(window(rain.mon, start=c(1949,1), end=c(1979,12)),sc=12)
+#' #SPI.cal <- SPEI::spi(window(rain.mon, start = c(1949, 1), end = c(1979, 12)), scale = 12)$fitted
 #'
 #' ## create paired response and predictors dataset for each station
 #' data.list <- list()
@@ -175,8 +177,8 @@ at.vt <- function(data, wf, J, boundary, cov.opt = "auto",
 #' )
 #'
 #' ## response SPI - validation
-#' # SPI.val <- SPI.calc(window(rain.mon, start=c(1979,1), end=c(2009,12)),sc=12)
-#' SPI.val <- SPEI::spi(window(rain.mon, start = c(1979, 1), end = c(2009, 12)), scale = 12)$fitted
+#' SPI.val <- SPI.calc(window(rain.mon, start=c(1979,1), end=c(2009,12)),sc=12)
+#' #SPI.val <- SPEI::spi(window(rain.mon, start = c(1979, 1), end = c(2009, 12)), scale = 12)$fitted
 #'
 #' ## create paired response and predictors dataset for each station
 #' data.list <- list()
@@ -234,8 +236,7 @@ at.vt.val <- function(data, J, dwt, detrend = FALSE) {
     V <- as.numeric(apply(B, 2, sd))
 
     dif <- sum(abs(Bn %*% V - dp.c))
-    if (dif > 10^-10) print(paste0("Difference between reconstructed and
-                                   original series: ", dif))
+    if (dif > 10^-10) print(paste0("Difference between reconstructed and original series: ", dif))
 
     # in case different J
     cov <- rep(0, J + 1)
